@@ -73,13 +73,13 @@ parse_get_data_format (const gchar  *option_name,
 static GOptionEntry entries[] = {
 #if defined HAVE_QMI_MESSAGE_WDA_SET_DATA_FORMAT
     { "wda-set-data-format", 0, 0, G_OPTION_ARG_STRING, &set_data_format_str,
-      "Set data format (allowed keys: link-layer-protocol (802-3|raw-ip), ul-protocol (tlp|qc-ncm|mbim|rndis|qmap), dl-protocol (tlp|qc-ncm|mbim|rndis|qmap), dl-datagram-max-size, dl-max-datagrams, ep-type (undefined|hsusb), ep-iface-number)",
+      "Set data format (allowed keys: link-layer-protocol (802-3|raw-ip), ul-protocol (tlp|qc-ncm|mbim|rndis|qmap|qmapv5), dl-protocol (tlp|qc-ncm|mbim|rndis|qmap|qmapv5), dl-datagram-max-size, dl-max-datagrams, ep-type (undefined|hsusb|pcie|embedded), ep-iface-number)",
       "[\"key=value,...\"]"
     },
 #endif
 #if defined HAVE_QMI_MESSAGE_WDA_GET_DATA_FORMAT
     { "wda-get-data-format", 0, G_OPTION_FLAG_OPTIONAL_ARG, G_OPTION_ARG_CALLBACK, parse_get_data_format,
-      "Get data format (allowed keys: ep-type (undefined|hsusb), ep-iface-number); also allows empty key list",
+      "Get data format (allowed keys: ep-type (undefined|hsusb|pcie|embedded), ep-iface-number); also allows empty key list",
       "[\"key=value,...\"]"
     },
 #endif
@@ -237,7 +237,8 @@ get_data_format_input_create (const gchar *str)
         return NULL;
     }
 
-    if (props.endpoint_type != QMI_DATA_ENDPOINT_TYPE_UNDEFINED &&
+    if ((props.endpoint_type != QMI_DATA_ENDPOINT_TYPE_UNDEFINED) &&
+        (props.endpoint_iface_number != QMI_WDA_ENDPOINT_INTERFACE_NUMBER_UNDEFINED) &&
         !qmi_message_wda_get_data_format_input_set_endpoint_info (
             input,
             props.endpoint_type,
@@ -247,16 +248,6 @@ get_data_format_input_create (const gchar *str)
         return NULL;
     }
 
-    if (props.endpoint_iface_number != QMI_WDA_ENDPOINT_INTERFACE_NUMBER_UNDEFINED &&
-        !qmi_message_wda_get_data_format_input_set_endpoint_info (
-            input,
-            QMI_DATA_ENDPOINT_TYPE_HSUSB,
-            props.endpoint_iface_number,
-            &error)) {
-        g_printerr ("error: could not set peripheral endpoint id: %s\n", error->message);
-        return NULL;
-    }
-
     return g_steal_pointer (&input);
 }
 
@@ -571,7 +562,6 @@ set_data_format_input_create (const gchar *str)
                         props.dl_protocol, error->message);
             g_error_free (error);
             goto error_out;
-
         }
 
         if (props.dl_datagram_max_size != QMI_WDA_DL_AGGREGATION_PROTOCOL_MAX_DATAGRAM_SIZE_UNDEFINED &&
@@ -583,7 +573,6 @@ set_data_format_input_create (const gchar *str)
                         props.dl_datagram_max_size, error->message);
             g_error_free (error);
             goto error_out;
-
         }
 
         if (props.dl_max_datagrams != QMI_WDA_DL_AGGREGATION_PROTOCOL_MAX_DATAGRAMS_UNDEFINED &&
@@ -604,7 +593,8 @@ set_data_format_input_create (const gchar *str)
             goto error_out;
         }
 
-        if (props.endpoint_type != QMI_DATA_ENDPOINT_TYPE_UNDEFINED &&
+        if ((props.endpoint_type != QMI_DATA_ENDPOINT_TYPE_UNDEFINED) &&
+            (props.endpoint_iface_number != QMI_WDA_ENDPOINT_INTERFACE_NUMBER_UNDEFINED) &&
             !qmi_message_wda_set_data_format_input_set_endpoint_info (
                 input,
                 props.endpoint_type,
@@ -613,19 +603,6 @@ set_data_format_input_create (const gchar *str)
             g_printerr ("error: could not set peripheral endpoint id: %s\n", error->message);
             g_error_free (error);
             goto error_out;
-
-        }
-
-        if (props.endpoint_iface_number != QMI_WDA_ENDPOINT_INTERFACE_NUMBER_UNDEFINED &&
-            !qmi_message_wda_set_data_format_input_set_endpoint_info (
-                input,
-                QMI_DATA_ENDPOINT_TYPE_HSUSB,
-                props.endpoint_iface_number,
-                &error)) {
-            g_printerr ("error: could not set peripheral endpoint id: %s\n", error->message);
-            g_error_free (error);
-            goto error_out;
-
         }
     }
     /* Old non key=value format, like this:
